@@ -14,6 +14,8 @@ from google.oauth2 import service_account
 import sqlalchemy
 import smtplib
 import ssl
+import requests
+import json
 
 
 class Logging:
@@ -680,3 +682,47 @@ class General:
             ][m == "y"],
             word + "d",
         ][m == "e"]
+
+
+class TeamsMessage:
+    """
+    Class contains functions to send a message via Microsoft Teams.
+    Note that a webhook needs to be created prior to execution, please consult the documentation
+    for more information: https://docs.microsoft.com/en-us/microsoftteams/platform/webhooks-and-connectors/how-to/add-incoming-webhook
+
+    """
+
+    def __init__(self, webhook: str):
+        """
+        In order to send a Teams notification to the relevant channel, the webhook created
+        must be specified.
+
+        Parameters
+        ----------
+        webhook: str, the webhook connected to a Teams channel.
+
+        """
+        self.webhook = webhook
+
+    def send_teams_message(self, message: str):
+        """
+        Sends a Microsoft Teams notification to a channel. This is specified by the webhook.
+
+        Parameters
+        ----------
+        message: str, the message to send.
+
+        Returns
+        -------
+        A Teams notification being sent to the relevant channel.
+
+        """
+        # Create payload
+        payload = {"text": message}
+
+        # Create headers
+        headers = {"Content-Type": "application/json"}
+
+        return requests.post(
+            url=self.webhook, headers=headers, data=json.dumps(payload)
+        )
